/*
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package org.ow2.petals.registry.api;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;

/**
 * The endpoint definition
 * 
 * @author Christophe HAMERLING - eBM WebSourcing
 * @author Charles Casadei - eBM WebSourcing
 */
public class Endpoint implements Serializable {
    
    private static final long serialVersionUID = -8159499352167678948L;

    /**
     * 
     */
    //TODO : make it transient and check the impact on petals
    private Document description;

    /**
     * The endpoint name
     */
    private String name;

    /**
     * The service name
     */
    private QName service;

    /**
     * The interfaces
     */
    private List<QName> interfaces;

    /**
     * Additional endpoint properties
     */
    private Map<String, String> properties;

    public Endpoint() {
        this.properties = new HashMap<String, String>();
        this.interfaces = new ArrayList<QName>();
    }

    public Document getDescription() {
        return this.description;
    }

    public QName getQName() {
        return new QName(this.name);
    }

    public void setQName(QName name) {
        this.name = name.getLocalPart();
    }

    public void setQName(String name) {
        this.name = name;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setName(QName name) {
        this.name = name.getLocalPart();
    }
    
    public Map<String, String> getProperties() {
        return this.properties;
    }

    public void setProperties(Map<String, String> properties) {
        this.properties = properties;
    }

    /**
     * @return the service
     */
    public QName getService() {
        return this.service;
    }

    /**
     * @param service
     *            the service to set
     */
    public void setService(QName service) {
        this.service = service;
    }

    /**
     * @return the interfaces
     */
    public List<QName> getInterfaces() {
        return this.interfaces;
    }

    /**
     * @param interfaces
     *            the interfaces to set
     */
    public void setInterfaces(List<QName> interfaces) {
        this.interfaces = interfaces;
    }

    public void setDescription(Document description) {
        this.description = description;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }

        final Endpoint other = (Endpoint) obj;
        
        if ((this.name == null) ? (other.name != null) : !this.name.equals(other.name)) {
            return false;
        }

        if (this.service != other.service && (this.service == null || !this.service.equals(other.service))) {
            return false;
        }

        if (this.interfaces != other.interfaces && this.interfaces != null) {

            if (this.interfaces.size() != other.interfaces.size()) {
                return false;
            }

            if (! this.interfaces.containsAll(other.interfaces)) {
                return false;
            }

            if (! other.interfaces.containsAll(this.interfaces)) {
                return false;
            }
        }

        if (this.properties != other.properties && this.properties != null) {

            if (this.properties.size() != other.properties.size()) {
                return false;
            }

            if (! this.properties.keySet().containsAll(other.properties.keySet())) {
                return false;
            }

            if (! other.properties.keySet().containsAll(this.properties.keySet())) {
                return false;
            }

            if (! this.properties.entrySet().containsAll(other.properties.entrySet())) {
                return false;
            }

            if (! other.properties.entrySet().containsAll(this.properties.entrySet())) {
                return false;
            }
        }

        return true;
    }
    
    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("Endpoint [name=");
        builder.append(this.name);
        builder.append(", interfaces=");
        builder.append(this.interfaces);
        builder.append(", service=");
        builder.append(this.service);
        builder.append(", properties=");
        builder.append(this.properties);
        builder.append(", isLocalEP=");
        builder.append("]");
        return builder.toString();
    }
}
